Installation instructions — cnnclustering documentation

# Installation instructions

## Requirements

The `cnnclustering` package is developed and tested in Python 3.8. Earlier versions >=3.6 may work as well, though. The package has a few third party Python package dependencies. We recommend to install the latest version of:

> - `matplotlib`

> - `numpy`

> - `scipy`

> - `pandas` (optional)

> - `tqdm`

> - `PyYAML`

If you want to compile the Cython extensions yourself, you will need to install `Cython` as well. The tests can be run after installing `pytest` and require `scikit-learn`.

## PyPi

    pip install cnnclustering

## Manual installation

Clone the source repository https://github.com/janjoswig/CNN and use the package `cnnclustering` as you prefer it, e.g. install it via pip.

    $ git clone https://github.com/janjoswig/CNN
    $ cd CNN
    $ pip install .